(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    134249,       3206]
NotebookOptionsPosition[    126956,       3080]
NotebookOutlinePosition[    127516,       3101]
CellTagsIndexPosition[    127473,       3098]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7c6823d8-1b6d-47fd-94fe-e17171908c1c"],

Cell["Chapter 6, Section 6.10.1", "Section",ExpressionUUID->"b8a4dc82-9288-43ab-86c8-ca741bc20902"],

Cell[TextData[{
 "Here we are going to derive explicit expressions for the secular and \
resonant terms associated with the motion of an asteroid at the 3:1 resonance \
with Jupiter.\n\nWe start by loading the ",
 StyleBox["DisturbingFunction", "Input"],
 " package.  In this example it is assumed that the file ",
 StyleBox["DisturbingFunction.m",
  FontWeight->"Bold"],
 " is located in the current directory/folder."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3765bf77-314d-4213-952a-f7910528cb4d"],

Cell["SetDirectory[\"/Users/carl/New_Book/New_Chapter_06\"];", "Input",
 CellChangeTimes->{3.86635954471481*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"2625adf5-311e-4bc8-8a25-c1ef671c42e0"],

Cell["<<DisturbingFunction.m;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"b32a3cee-6374-49ef-816a-ff3d748c8f77"],

Cell[TextData[{
 "Show how the function ",
 StyleBox["ValidArguments", "Input"],
 " is used."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"90bc5eae-1a96-4345-891f-d5eb1fb9e062"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ValidArguments"}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"a11ae7ed-cb99-4dd5-8cd0-d6b5b201628b"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"ValidArguments[c1,c2,pw] produces an ordered list \
of valid arguments of the expansion of the disturbing function up to and \
including degree 'pw' which start with \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda].  \
The components of each argument, {\\!\\(\\*SubscriptBox[\\(c\\), \\(1\\)]\\),\
\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \
\\(3\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(4\\)]\\),\\!\\(\\*SubscriptBox[\
\\(c\\), \\(5\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)}, represent \
the argument \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda]+\\!\
\\(\\*SubscriptBox[\\(c\\), \\(3\\)]\\)\[CurlyPi]'+\\!\\(\\*SubscriptBox[\\(c\
\\), \\(4\\)]\\)\[CurlyPi]+\\!\\(\\*SubscriptBox[\\(c\\), \\(5\\)]\\)\
\[CapitalOmega]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)\[CapitalOmega].  \
c1 and c2 are integers of the form, e.g. j and i-j, where i, the order of the \
resonance, is an integer.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"ValidArguments", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`c1_", ",", 
                    "DisturbingFunction`Private`c2_", ",", 
                    "DisturbingFunction`Private`n_Integer"}], "]"}], ":=", 
                    RowBox[{"Module", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`absarglist", ",", 
                    "DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`degree", ",", 
                    "DisturbingFunction`Private`temparg", ",", 
                    RowBox[{"DisturbingFunction`Private`order", "=", 
                    RowBox[{"Abs", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`c1", "+", 
                    "DisturbingFunction`Private`c2"}], "]"}]}], ",", 
                    
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    "DisturbingFunction`Private`c1"}], ",", 
                    
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    "DisturbingFunction`Private`c2"}], ",", 
                    "DisturbingFunction`Private`ii", ",", 
                    "DisturbingFunction`Private`jj", ",", 
                    "DisturbingFunction`Private`kk", ",", 
                    "DisturbingFunction`Private`ll", ",", 
                    "DisturbingFunction`Private`var"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`kk", ",", 
                    "DisturbingFunction`Private`ll", ",", 
                    "DisturbingFunction`Private`ii", ",", 
                    "DisturbingFunction`Private`jj"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`ii", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], ",", "0", ",", 
                    RowBox[{"-", "DisturbingFunction`Private`n"}]}], "]"}], 
                    ",", "DisturbingFunction`Private`n"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`jj", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`kk", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`jj", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`ll", ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`order", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`ii", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`jj", "\[Equal]", 
                    "0"}], "&&", 
                    
                    RowBox[{"DisturbingFunction`Private`kk", "\[Equal]", 
                    "0"}]}], ",", "0", ",", 
                    RowBox[{
                    RowBox[{"-", "DisturbingFunction`Private`n"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}], "+", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`kk", 
                    "]"}]}]}], "]"}], ",", 
                    RowBox[{"DisturbingFunction`Private`n", "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`ii", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}], "-", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`kk", 
                    "]"}]}]}], "}"}]}], "]"}], ",", "3"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Select", "[", 
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`order", "+", 
                    RowBox[{"Plus", "@@", "#1"}]}], "\[Equal]", "0"}], 
                    "&"}]}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Select", "[", 
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    RowBox[{
                    RowBox[{"EvenQ", "[", 
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    
                    RowBox[{"#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "+", 
                    
                    RowBox[{"#1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}], "&"}]}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`absarglist", "=", 
                    
                    RowBox[{"Abs", "/@", 
                    "DisturbingFunction`Private`arglist"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`temparg", "=", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", "/.", 
                    "\[VeryThinSpace]", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x1_", ",", 
                    "DisturbingFunction`Private`x2_", ",", 
                    "DisturbingFunction`Private`x3_", ",", 
                    "DisturbingFunction`Private`x4_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x3", ",", 
                    "DisturbingFunction`Private`x4", ",", 
                    "DisturbingFunction`Private`x1", ",", 
                    "DisturbingFunction`Private`x2"}], "}"}]}]}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`degree", "=", 
                    RowBox[{"Apply", "[", 
                    
                    RowBox[{"Plus", ",", 
                    "DisturbingFunction`Private`absarglist", ",", "1"}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    
                    RowBox[{"Transpose", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], ",", 
                    "DisturbingFunction`Private`temparg"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Prepend", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`absarglist"}], "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`arglist", "=", 
                    RowBox[{"Sort", "[", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"Prepend", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`arglist", ",", 
                    "DisturbingFunction`Private`degree"}], "]"}], "]"}], 
                    "]"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`var", "=", 
                    RowBox[{"Variables", "[", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`c1", ",", 
                    "DisturbingFunction`Private`c2"}], "}"}], "]"}]}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`var", "=!=", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{"DisturbingFunction`Private`c1", ",", 
                    
                    RowBox[{"DisturbingFunction`Private`var", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    ",", "1"}], "]"}], "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c1"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c2"}]}]}]}], 
                    "]"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`c1", "<", "0"}], ",", 
                    
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`ac1", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c1"}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`ac2", "=", 
                    RowBox[{"-", "DisturbingFunction`Private`c2"}]}]}]}], 
                    "]"}]}], "]"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"Length", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], "=!=", "0"}],
                     ",", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"Drop", "[", 
                    RowBox[{
                    
                    RowBox[{"Transpose", "[", 
                    "DisturbingFunction`Private`arglist", "]"}], ",", "3"}], 
                    "]"}], "]"}], "/.", "\[VeryThinSpace]", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`x1_", ",", 
                    "DisturbingFunction`Private`x2_", ",", 
                    "DisturbingFunction`Private`x3_", ",", 
                    "DisturbingFunction`Private`x4_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`ac1", ",", 
                    "DisturbingFunction`Private`ac2", ",", 
                    "DisturbingFunction`Private`x3", ",", 
                    "DisturbingFunction`Private`x4", ",", 
                    "DisturbingFunction`Private`x1", ",", 
                    "DisturbingFunction`Private`x2"}], "}"}]}]}], ",", 
                    "DisturbingFunction`Private`arglist"}], "]"}]}]}], 
                    "]"}]}]}, {" "}}, 
                  GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], "\<\"DisturbingFunction`ValidArguments\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"ValidArguments[c1,c2,pw] produces an ordered list \
of valid arguments of the expansion of the disturbing function up to and \
including degree 'pw' which start with \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda].  \
The components of each argument, {\\!\\(\\*SubscriptBox[\\(c\\), \\(1\\)]\\),\
\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \
\\(3\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(4\\)]\\),\\!\\(\\*SubscriptBox[\
\\(c\\), \\(5\\)]\\),\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)}, represent \
the argument \\!\\(\\*SubscriptBox[\\(c\\), \
\\(1\\)]\\)\[Lambda]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(2\\)]\\)\[Lambda]+\\!\
\\(\\*SubscriptBox[\\(c\\), \\(3\\)]\\)\[CurlyPi]'+\\!\\(\\*SubscriptBox[\\(c\
\\), \\(4\\)]\\)\[CurlyPi]+\\!\\(\\*SubscriptBox[\\(c\\), \\(5\\)]\\)\
\[CapitalOmega]'+\\!\\(\\*SubscriptBox[\\(c\\), \\(6\\)]\\)\[CapitalOmega].  \
c1 and c2 are integers of the form, e.g. j and i-j, where i, the order of the \
resonance, is an integer.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "ValidArguments[c1,c2,pw] produces an ordered list of valid arguments of \
the expansion of the disturbing function up to and including degree 'pw' \
which start with \!\(\*SubscriptBox[\(c\), \
\(1\)]\)\[Lambda]'+\!\(\*SubscriptBox[\(c\), \(2\)]\)\[Lambda].  The \
components of each argument, {\!\(\*SubscriptBox[\(c\), \
\(1\)]\),\!\(\*SubscriptBox[\(c\), \(2\)]\),\!\(\*SubscriptBox[\(c\), \
\(3\)]\),\!\(\*SubscriptBox[\(c\), \(4\)]\),\!\(\*SubscriptBox[\(c\), \
\(5\)]\),\!\(\*SubscriptBox[\(c\), \(6\)]\)}, represent the argument \
\!\(\*SubscriptBox[\(c\), \(1\)]\)\[Lambda]'+\!\(\*SubscriptBox[\(c\), \(2\)]\
\)\[Lambda]+\!\(\*SubscriptBox[\(c\), \(3\)]\)\[CurlyPi]'+\!\(\*SubscriptBox[\
\(c\), \(4\)]\)\[CurlyPi]+\!\(\*SubscriptBox[\(c\), \(5\)]\)\[CapitalOmega]'+\
\!\(\*SubscriptBox[\(c\), \(6\)]\)\[CapitalOmega].  c1 and c2 are integers of \
the form, e.g. j and i-j, where i, the order of the resonance, is an \
integer.", "Documentation" -> None, "OwnValues" -> None, "UpValues" -> None, 
    "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`ValidArguments, {
      DisturbingFunction`ValidArguments[
         Pattern[DisturbingFunction`Private`c1, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`c2, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`n, 
          Blank[Integer]]] :> 
       Module[{DisturbingFunction`Private`absarglist, 
          DisturbingFunction`Private`arglist, 
          DisturbingFunction`Private`degree, 
          DisturbingFunction`Private`temparg, 
          DisturbingFunction`Private`order = 
          Abs[DisturbingFunction`Private`c1 + DisturbingFunction`Private`c2], 
          DisturbingFunction`Private`ac1 = DisturbingFunction`Private`c1, 
          DisturbingFunction`Private`ac2 = DisturbingFunction`Private`c2, 
          DisturbingFunction`Private`ii, DisturbingFunction`Private`jj, 
          DisturbingFunction`Private`kk, DisturbingFunction`Private`ll, 
          DisturbingFunction`Private`var}, 
         DisturbingFunction`Private`arglist = Flatten[
            
            Table[{DisturbingFunction`Private`kk, 
              DisturbingFunction`Private`ll, DisturbingFunction`Private`ii, 
              DisturbingFunction`Private`jj}, {
             DisturbingFunction`Private`ii, 
              If[
              DisturbingFunction`Private`order == 0, 0, -
               DisturbingFunction`Private`n], DisturbingFunction`Private`n}, {
             DisturbingFunction`Private`jj, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii]}, {DisturbingFunction`Private`kk, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0, 
                DisturbingFunction`Private`jj == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii] + 
               Abs[DisturbingFunction`Private`jj]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii] - Abs[
              DisturbingFunction`Private`jj]}, {DisturbingFunction`Private`ll, 
              If[
               And[
               DisturbingFunction`Private`order == 0, 
                DisturbingFunction`Private`ii == 0, 
                DisturbingFunction`Private`jj == 0, 
                DisturbingFunction`Private`kk == 0], 
               0, -DisturbingFunction`Private`n + 
               Abs[DisturbingFunction`Private`ii] + 
               Abs[DisturbingFunction`Private`jj] + 
               Abs[DisturbingFunction`Private`kk]], 
              DisturbingFunction`Private`n - Abs[
              DisturbingFunction`Private`ii] - Abs[
              DisturbingFunction`Private`jj] - Abs[
              DisturbingFunction`Private`kk]}], 3]; 
         DisturbingFunction`Private`arglist = 
          Select[DisturbingFunction`Private`arglist, 
            DisturbingFunction`Private`order + Apply[Plus, #] == 0& ]; 
         DisturbingFunction`Private`arglist = 
          Select[DisturbingFunction`Private`arglist, EvenQ[
             Abs[Part[#, 1] + Part[#, 2]]]& ]; 
         DisturbingFunction`Private`absarglist = 
          Map[Abs, DisturbingFunction`Private`arglist]; 
         DisturbingFunction`Private`temparg = 
          ReplaceAll[DisturbingFunction`Private`arglist, {
              Pattern[DisturbingFunction`Private`x1, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x2, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x3, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x4, 
               Blank[]]} :> {
             DisturbingFunction`Private`x3, DisturbingFunction`Private`x4, 
              DisturbingFunction`Private`x1, DisturbingFunction`Private`x2}]; 
         DisturbingFunction`Private`degree = 
          Apply[Plus, DisturbingFunction`Private`absarglist, 1]; 
         DisturbingFunction`Private`arglist = Prepend[
            Transpose[DisturbingFunction`Private`arglist], 
            DisturbingFunction`Private`temparg]; 
         DisturbingFunction`Private`arglist = 
          Prepend[DisturbingFunction`Private`arglist, 
            DisturbingFunction`Private`absarglist]; 
         DisturbingFunction`Private`arglist = Sort[
            Transpose[
             Prepend[
             DisturbingFunction`Private`arglist, 
              DisturbingFunction`Private`degree]]]; 
         DisturbingFunction`Private`var = 
          Variables[{
            DisturbingFunction`Private`c1, DisturbingFunction`Private`c2}]; 
         If[DisturbingFunction`Private`var =!= {}, 
           If[Coefficient[DisturbingFunction`Private`c1, 
              Part[DisturbingFunction`Private`var, 1], 1] == -1, 
            DisturbingFunction`Private`ac1 = -DisturbingFunction`Private`c1; 
            DisturbingFunction`Private`ac2 = -DisturbingFunction`Private`c2], 
           
           If[
           DisturbingFunction`Private`c1 < 0, 
            DisturbingFunction`Private`ac1 = -DisturbingFunction`Private`c1; 
            DisturbingFunction`Private`ac2 = -DisturbingFunction`Private`c2]]; 
         If[Length[DisturbingFunction`Private`arglist] =!= 0, 
           ReplaceAll[
            Transpose[
             Drop[
              Transpose[DisturbingFunction`Private`arglist], 3]], {
              Pattern[DisturbingFunction`Private`x1, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x2, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x3, 
               Blank[]], 
              Pattern[DisturbingFunction`Private`x4, 
               Blank[]]} :> {
             DisturbingFunction`Private`ac1, DisturbingFunction`Private`ac2, 
              DisturbingFunction`Private`x3, DisturbingFunction`Private`x4, 
              DisturbingFunction`Private`x1, DisturbingFunction`Private`x2}], 
           DisturbingFunction`Private`arglist]]}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`ValidArguments"|>, False]]], "Output",
 CellChangeTimes->{3.866436898650391*^9, 3.8664372642656727`*^9, 
  3.866437433849409*^9, 3.890974232605032*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"20ee3eb5-758c-49ef-aace-5cd4e914e389"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 StyleBox["ValidArguments", "Input"],
 " to find the secular arguments (associated with terms up to second order in \
the eccentricities and inclinations), i.e. those independent of both mean \
longitudes, or, of a form 0\[Lambda]'+0\[Lambda]+ ... .  There are 3 such \
arguments to second order."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"260ff44d-3a45-458e-9e78-123e4f85f663"],

Cell[CellGroupData[{

Cell["argsec = ValidArguments[0,0,2]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"31211f09-0101-4959-9ef7-d9361c9da52b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811324374311077*^9, 3.866436943435484*^9, 
  3.866437264308214*^9, 3.8664374338797092`*^9, 3.89097423261595*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"432c14a3-3ce8-4081-a45d-03c2803faac4"]
}, Open  ]],

Cell[TextData[{
 "Show how the function ",
 StyleBox["DisturbingFunctionE", "Input"],
 " is used."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0d6cb01a-674d-4d84-b09a-6753d329ac6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DisturbingFunctionE"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"ac212f06-4691-4f7b-a713-dcc098d035fa"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"DisturbingFunctionE[argument,pmax] finds the full \
coefficient of the disturbing function (direct and indirect parts) which \
contains the cosine of argument for an external perturber.\"\>", 
             "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"DisturbingFunctionE", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`argument_List", ",", 
                    "DisturbingFunction`Private`pmax_Integer"}], "]"}], ":=", 
                    
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"\[ScriptCapitalG]", " ", 
                    SuperscriptBox[
                    "m", "\[Prime]", MultilineFunction -> None]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DirectPart", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`argument", ",", 
                    "DisturbingFunction`Private`pmax"}], "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[Lambda]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    " ", "\[Lambda]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CurlyPi]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
                    " ", "\[CurlyPi]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CapitalOmega]", "\[Prime]", MultilineFunction -> 
                    None]}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
                    " ", "\[CapitalOmega]"}]}], "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"IndirectPartE", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`argument", ",", 
                    "DisturbingFunction`Private`pmax"}], "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[Lambda]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    " ", "\[Lambda]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CurlyPi]", "\[Prime]", MultilineFunction -> None]}], 
                    "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
                    " ", "\[CurlyPi]"}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
                    " ", 
                    SuperscriptBox[
                    "\[CapitalOmega]", "\[Prime]", MultilineFunction -> 
                    None]}], "+", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`argument", 
                    "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
                    " ", "\[CapitalOmega]"}]}], "]"}]}]}], ")"}]}], 
                    SuperscriptBox[
                    "a", "\[Prime]", MultilineFunction -> None]]}]}, {" "}}, 
                  GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], \
"\<\"DisturbingFunction`DisturbingFunctionE\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"DisturbingFunctionE[argument,pmax] finds the full \
coefficient of the disturbing function (direct and indirect parts) which \
contains the cosine of argument for an external perturber.\"\>", 
             "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "DisturbingFunctionE[argument,pmax] finds the full coefficient of the \
disturbing function (direct and indirect parts) which contains the cosine of \
argument for an external perturber.", "Documentation" -> None, "OwnValues" -> 
    None, "UpValues" -> None, "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`DisturbingFunctionE, {
      DisturbingFunction`DisturbingFunctionE[
         Pattern[DisturbingFunction`Private`argument, 
          Blank[List]], 
         Pattern[DisturbingFunction`Private`pmax, 
          Blank[Integer]]] :> ($CellContext`\[ScriptCapitalG] (
          Derivative[1][$CellContext`m]/Derivative[1][$CellContext`a])) (
         DisturbingFunction`DirectPart[
           DisturbingFunction`Private`argument, 
            DisturbingFunction`Private`pmax] 
          Cos[Part[DisturbingFunction`Private`argument, 1] 
             Derivative[1][$CellContext`\[Lambda]] + 
            Part[DisturbingFunction`Private`argument, 
               2] $CellContext`\[Lambda] + 
            Part[DisturbingFunction`Private`argument, 3] 
             Derivative[1][$CellContext`\[CurlyPi]] + 
            Part[DisturbingFunction`Private`argument, 
               4] $CellContext`\[CurlyPi] + 
            Part[DisturbingFunction`Private`argument, 5] 
             Derivative[1][$CellContext`\[CapitalOmega]] + 
            Part[DisturbingFunction`Private`argument, 
               6] $CellContext`\[CapitalOmega]] + $CellContext`\[Alpha] 
          DisturbingFunction`IndirectPartE[
           DisturbingFunction`Private`argument, 
            DisturbingFunction`Private`pmax] 
          Cos[Part[DisturbingFunction`Private`argument, 1] 
             Derivative[1][$CellContext`\[Lambda]] + 
            Part[DisturbingFunction`Private`argument, 
               2] $CellContext`\[Lambda] + 
            Part[DisturbingFunction`Private`argument, 3] 
             Derivative[1][$CellContext`\[CurlyPi]] + 
            Part[DisturbingFunction`Private`argument, 
               4] $CellContext`\[CurlyPi] + 
            Part[DisturbingFunction`Private`argument, 5] 
             Derivative[1][$CellContext`\[CapitalOmega]] + 
            Part[DisturbingFunction`Private`argument, 
               6] $CellContext`\[CapitalOmega]])}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`DisturbingFunctionE"|>, False]]], "Output",
 CellChangeTimes->{3.811324374395733*^9, 3.866436946938621*^9, 
  3.866437264394473*^9, 3.8664374339562893`*^9, 3.8909742326842823`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"a77ee3af-224e-4f87-a278-48ec045005f5"]
}, Open  ]],

Cell[TextData[{
 "Map ",
 StyleBox["DisturbingFunctionE", "Input"],
 " on to each of the secular arguments in order to find the terms (to second \
order) associated with each."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"66038f9b-3952-4f07-871c-d7d9902f4959"],

Cell[CellGroupData[{

Cell["secular = Map[DisturbingFunctionE[#,2]&,argsec]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"e3713d9e-94cd-4d07-8949-6d34b274f4c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["a", "\[Prime]",
      MultilineFunction->None]], 
    RowBox[{"\[ScriptCapitalG]", " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "0", ",", "0"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", 
        SuperscriptBox["e", "2"], " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "0", ",", "1"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "8"], " ", 
        SuperscriptBox["e", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "0", ",", "2"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["s", "2"], " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["3", "2"], ",", "1", ",", "0"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "0", ",", "1"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["e", "\[Prime]",
           MultilineFunction->None], ")"}], "2"]}], "+", 
       RowBox[{
        FractionBox["1", "8"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "0", ",", "2"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["e", "\[Prime]",
           MultilineFunction->None], ")"}], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["3", "2"], ",", "1", ",", "0"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["s", "\[Prime]",
           MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]}], ",", 
   FractionBox[
    RowBox[{"\[ScriptCapitalG]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[CurlyPi]", "-", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", "e", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "1", ",", "0"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "e", " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "1", ",", "1"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", "e", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "1", ",", "2"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}]}], ")"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None]}], 
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None]], ",", 
   FractionBox[
    RowBox[{"s", " ", "\[ScriptCapitalG]", " ", "\[Alpha]", " ", 
     RowBox[{"b", "[", 
      RowBox[{
       FractionBox["3", "2"], ",", "1", ",", "0"}], "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[CapitalOmega]", "-", 
       SuperscriptBox["\[CapitalOmega]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None], " ", 
     SuperscriptBox["s", "\[Prime]",
      MultilineFunction->None]}], 
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None]]}], "}"}]], "Output",
 CellChangeTimes->{3.811324374449889*^9, 3.866436951461731*^9, 
  3.8664372645008783`*^9, 3.8664374340074043`*^9, 3.8909742327269487`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"68d16c21-7636-4886-8a3e-3b98f5237e79"]
}, Open  ]],

Cell[TextData[{
 "Now use ",
 StyleBox["ValidArguments", "Input"],
 " to find the terms (up to second order) associated with the arguments of \
the form 3\[Lambda]'\[Dash]\[Lambda]+... .  There are 6 such arguments."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e9805ec4-b033-45f7-a9e4-a1a32320b609"],

Cell[CellGroupData[{

Cell["args31 = ValidArguments[3,-1,2]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"6022d9e9-3b16-4b78-abc9-087d480a87e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
     RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811324374998919*^9, 3.8664369576257477`*^9, 
  3.866437264540422*^9, 3.86643743403076*^9, 3.890974232743828*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"39d7d848-981a-4eb6-96b4-abcdab884dde"]
}, Open  ]],

Cell[TextData[{
 "Map ",
 StyleBox["DisturbingFunctionE", "Input"],
 " on to each of the resonant arguments in order to find the terms (to second \
order) associated with each."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2712ef4c-b71f-4f10-a35b-baac361bb4c4"],

Cell[CellGroupData[{

Cell["resonant = Map[DisturbingFunctionE[#,2]&,args31]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"72fead30-71ba-4d61-b903-5a0680739fc5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"\[ScriptCapitalG]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["21", "8"], " ", 
        SuperscriptBox["e", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "3", ",", "0"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["5", "4"], " ", 
        SuperscriptBox["e", "2"], " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "3", ",", "1"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "8"], " ", 
        SuperscriptBox["e", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "3", ",", "2"}], "]"}]}]}], ")"}], " ", 
     
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None]}], 
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None]], ",", 
   FractionBox[
    RowBox[{"\[ScriptCapitalG]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "+", "\[CurlyPi]", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "e", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "2", ",", "0"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{
        FractionBox["5", "2"], " ", "e", " ", "\[Alpha]", " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "2", ",", "1"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", "e", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"b", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "2", ",", "2"}], "]"}], " ", 
        SuperscriptBox["e", "\[Prime]",
         MultilineFunction->None]}]}], ")"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None]}], 
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None]], ",", 
   FractionBox[
    RowBox[{"\[ScriptCapitalG]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["27", "8"]}], " ", "\[Alpha]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Lambda]", "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Lambda]", "\[Prime]",
            MultilineFunction->None]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[CurlyPi]", "\[Prime]",
            MultilineFunction->None]}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["e", "\[Prime]",
           MultilineFunction->None], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Lambda]", "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Lambda]", "\[Prime]",
            MultilineFunction->None]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[CurlyPi]", "\[Prime]",
            MultilineFunction->None]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["17", "8"], " ", 
           RowBox[{"b", "[", 
            RowBox[{
             FractionBox["1", "2"], ",", "1", ",", "0"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox["e", "\[Prime]",
              MultilineFunction->None], ")"}], "2"]}], "+", 
          RowBox[{
           FractionBox["5", "4"], " ", "\[Alpha]", " ", 
           RowBox[{"b", "[", 
            RowBox[{
             FractionBox["1", "2"], ",", "1", ",", "1"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox["e", "\[Prime]",
              MultilineFunction->None], ")"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "8"], " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           RowBox[{"b", "[", 
            RowBox[{
             FractionBox["1", "2"], ",", "1", ",", "2"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             SuperscriptBox["e", "\[Prime]",
              MultilineFunction->None], ")"}], "2"]}]}], ")"}]}]}], ")"}], 
     " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None]}], 
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "2"], " ", "\[ScriptCapitalG]", " ", "\[Alpha]", " ", 
     RowBox[{"b", "[", 
      RowBox[{
       FractionBox["3", "2"], ",", "2", ",", "0"}], "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"2", " ", "\[CapitalOmega]"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "\[Prime]",
      MultilineFunction->None]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"s", " ", "\[ScriptCapitalG]", " ", "\[Alpha]", " ", 
      RowBox[{"b", "[", 
       RowBox[{
        FractionBox["3", "2"], ",", "2", ",", "0"}], "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Lambda]", "+", "\[CapitalOmega]", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Lambda]", "\[Prime]",
          MultilineFunction->None]}], "+", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}], "]"}], " ", 
      SuperscriptBox["m", "\[Prime]",
       MultilineFunction->None], " ", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None]}], 
     SuperscriptBox["a", "\[Prime]",
      MultilineFunction->None]]}], ",", 
   FractionBox[
    RowBox[{"\[ScriptCapitalG]", " ", "\[Alpha]", " ", 
     RowBox[{"b", "[", 
      RowBox[{
       FractionBox["3", "2"], ",", "2", ",", "0"}], "]"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Lambda]", "\[Prime]",
         MultilineFunction->None]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[CapitalOmega]", "\[Prime]",
         MultilineFunction->None]}]}], "]"}], " ", 
     SuperscriptBox["m", "\[Prime]",
      MultilineFunction->None], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["s", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "\[Prime]",
      MultilineFunction->None]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.811324375051269*^9, 3.866436961654065*^9, 
  3.866437264588266*^9, 3.866437434076844*^9, 3.890974232767721*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"b51c1907-5573-4757-823a-0bfe67249ea5"]
}, Open  ]],

Cell["\<\
Define the value of \[Alpha] to be used in the calculation of the Laplace \
coefficients (see Eq.(6.206)).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fe8d2a07-1fd8-4b78-979a-90242bdc7820"],

Cell[CellGroupData[{

Cell["\[Alpha] = N[(1/3)^(2/3)*(1/(1+1/1047.355))^(1/3)]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"f124f71d-c80f-4d13-a5e3-524a674bf933"],

Cell[BoxData["0.48059694966028293`"], "Output",
 CellChangeTimes->{3.811324375058387*^9, 3.86643696720989*^9, 
  3.8664372646277733`*^9, 3.866437434103709*^9, 3.8909742327754803`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"e97f855a-6950-4286-a864-91aa9f4baef2"]
}, Open  ]],

Cell[TextData[{
 "Show how the function ",
 StyleBox["LaplaceCoefficient", "Input"],
 " is used."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"73613459-2158-445a-9de8-827677fe456c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "LaplaceCoefficient"}]], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"e3683508-4f23-42f8-805e-6e85ecc05d6d"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"LaplaceCoefficient[s,j,a,n] gives the nth \
derivative of the Laplace coefficient b(s,j)(a) as a numerical value. s is a \
half-integer (e.g. 1/2, 3/2); j, n are integers.\"\>", "InformationUsageText",
             
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"LaplaceCoefficient", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`s_", ",", 
                    "DisturbingFunction`Private`jj_Integer", ",", 
                    "DisturbingFunction`Private`a_", ",", 
                    "DisturbingFunction`Private`n_Integer"}], "]"}], ":=", 
                    RowBox[{"Module", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"DisturbingFunction`Private`outside", ",", 
                    RowBox[{"DisturbingFunction`Private`j", "=", 
                    
                    RowBox[{"Abs", "[", "DisturbingFunction`Private`jj", 
                    "]"}]}], ",", "DisturbingFunction`Private`cterm", ",", 
                    "DisturbingFunction`Private`cbterm", ",", 
                    "DisturbingFunction`Private`csum", ",", 
                    "DisturbingFunction`Private`i", ",", 
                    "DisturbingFunction`Private`k"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`outside", "=", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"DisturbingFunction`Private`k", "=", "0"}], 
                    RowBox[{"DisturbingFunction`Private`j", "-", "1"}]], 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`k"}], ")"}]}], ")"}], " ", 
                    SuperscriptBox["DisturbingFunction`Private`a", 
                    
                    RowBox[{"DisturbingFunction`Private`j", "-", 
                    "DisturbingFunction`Private`n"}]]}], 
                    RowBox[{"DisturbingFunction`Private`j", "!"}]]}], ";", 
                    RowBox[{"DisturbingFunction`Private`cterm", "=", "1"}], 
                    ";", 
                    RowBox[{"DisturbingFunction`Private`cbterm", "=", 
                    RowBox[{"DisturbingFunction`Private`cterm", " ", 
                    RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"DisturbingFunction`Private`k", "=", "0"}], 
                    RowBox[{"DisturbingFunction`Private`n", "-", "1"}]], 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`j", "-", 
                    "DisturbingFunction`Private`k"}], ")"}]}]}]}], ";", 
                    RowBox[{"For", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`i", "=", "1"}], ";", 
                    
                    RowBox[{"DisturbingFunction`Private`csum", "=", 
                    "DisturbingFunction`Private`cbterm"}]}], ",", 
                    RowBox[{
                    
                    RowBox[{"DisturbingFunction`Private`cbterm", ">", 
                    "$MachineEpsilon"}], "||", 
                    
                    RowBox[{"DisturbingFunction`Private`cbterm", "\[Equal]", 
                    "0"}]}], ",", 
                    RowBox[{"DisturbingFunction`Private`i", "++"}], ",", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`cterm", "=", 
                    FractionBox[
                    RowBox[{"DisturbingFunction`Private`cterm", " ", 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`i", "-", "1"}], ")"}], " ", 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`j", "+", 
                    "DisturbingFunction`Private`i", "-", "1"}], ")"}], " ", 
                    SuperscriptBox["DisturbingFunction`Private`a", "2"]}], 
                    RowBox[{"DisturbingFunction`Private`i", " ", 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`j", "+", 
                    "DisturbingFunction`Private`i"}], ")"}]}]]}], ";", 
                    RowBox[{"DisturbingFunction`Private`cbterm", "=", 
                    RowBox[{"DisturbingFunction`Private`cterm", " ", 
                    RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"DisturbingFunction`Private`k", "=", "0"}], 
                    RowBox[{"DisturbingFunction`Private`n", "-", "1"}]], 
                    RowBox[{"(", 
                    RowBox[{"DisturbingFunction`Private`j", "+", 
                    RowBox[{"2", " ", "DisturbingFunction`Private`i"}], "-", 
                    "DisturbingFunction`Private`k"}], ")"}]}]}]}], ";", 
                    RowBox[{"DisturbingFunction`Private`csum", "=", 
                    
                    RowBox[{"DisturbingFunction`Private`csum", "+", 
                    "DisturbingFunction`Private`cbterm"}]}]}]}], "]"}], ";", 
                    RowBox[{"Expand", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`outside", " ", 
                    "DisturbingFunction`Private`csum"}], "]"}]}]}], 
                    "]"}]}]}, {" "}}, 
                  GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], "\<\"DisturbingFunction`LaplaceCoefficient\
\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"LaplaceCoefficient[s,j,a,n] gives the nth \
derivative of the Laplace coefficient b(s,j)(a) as a numerical value. s is a \
half-integer (e.g. 1/2, 3/2); j, n are integers.\"\>", "InformationUsageText",
             
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "LaplaceCoefficient[s,j,a,n] gives the nth derivative of the Laplace \
coefficient b(s,j)(a) as a numerical value. s is a half-integer (e.g. 1/2, \
3/2); j, n are integers.", "Documentation" -> None, "OwnValues" -> None, 
    "UpValues" -> None, "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`LaplaceCoefficient, {
      DisturbingFunction`LaplaceCoefficient[
         Pattern[DisturbingFunction`Private`s, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`jj, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`a, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`n, 
          Blank[Integer]]] :> 
       Module[{DisturbingFunction`Private`outside, 
          DisturbingFunction`Private`j = Abs[DisturbingFunction`Private`jj], 
          DisturbingFunction`Private`cterm, DisturbingFunction`Private`cbterm,
           DisturbingFunction`Private`csum, DisturbingFunction`Private`i, 
          DisturbingFunction`Private`k}, 
         DisturbingFunction`Private`outside = 
          2 (Product[
             DisturbingFunction`Private`s + DisturbingFunction`Private`k, {
              DisturbingFunction`Private`k, 0, DisturbingFunction`Private`j - 
               1}]/Factorial[DisturbingFunction`Private`j]) 
           DisturbingFunction`Private`a^(DisturbingFunction`Private`j - 
             DisturbingFunction`Private`n); 
         DisturbingFunction`Private`cterm = 1; 
         DisturbingFunction`Private`cbterm = 
          DisturbingFunction`Private`cterm 
           Product[DisturbingFunction`Private`j - 
             DisturbingFunction`Private`k, {
             DisturbingFunction`Private`k, 0, DisturbingFunction`Private`n - 
              1}]; For[
          DisturbingFunction`Private`i = 1; 
           DisturbingFunction`Private`csum = 
            DisturbingFunction`Private`cbterm, 
           Or[
           DisturbingFunction`Private`cbterm > $MachineEpsilon, 
            DisturbingFunction`Private`cbterm == 0], 
           Increment[DisturbingFunction`Private`i], 
           DisturbingFunction`Private`cterm = 
            DisturbingFunction`Private`cterm (DisturbingFunction`Private`s + 
              DisturbingFunction`Private`i - 
              1) (((DisturbingFunction`Private`s + 
                DisturbingFunction`Private`j + DisturbingFunction`Private`i - 
                1)/DisturbingFunction`Private`i)/(
              DisturbingFunction`Private`j + DisturbingFunction`Private`i)) 
             DisturbingFunction`Private`a^2; 
           DisturbingFunction`Private`cbterm = 
            DisturbingFunction`Private`cterm 
             Product[DisturbingFunction`Private`j + 
               2 DisturbingFunction`Private`i - 
               DisturbingFunction`Private`k, {
               DisturbingFunction`Private`k, 0, DisturbingFunction`Private`n - 
                1}]; DisturbingFunction`Private`csum = 
            DisturbingFunction`Private`csum + 
             DisturbingFunction`Private`cbterm]; 
         Expand[DisturbingFunction`Private`outside 
           DisturbingFunction`Private`csum]]}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`LaplaceCoefficient"|>, False]]], "Output",
 CellChangeTimes->{3.8113243751457577`*^9, 3.8664369704431353`*^9, 
  3.8664372647109413`*^9, 3.8664374341838512`*^9, 3.890974232845501*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"fc216080-266c-4c4a-a5bb-f377c82b8afa"]
}, Open  ]],

Cell["\<\
Calculate numerical values for the terms associated with the secular \
arguments ...\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"644a6206-4520-4e97-a620-0b87ba704d4c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secterms", " ", "=", " ", "\n", 
  RowBox[{"secular", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[ScriptCapitalG]", "->", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"m", "'"}], "->", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"a", "'"}], "->", "1"}], ",", "\n", " ", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"s_", ",", " ", "j_", ",", " ", "nd_"}], "]"}], " ", ":>", " ", 
      RowBox[{"LaplaceCoefficient", "[", 
       RowBox[{"s", ",", "j", ",", "\[Alpha]", ",", "nd"}], "]"}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.8664369790018044`*^9, 3.866436979015835*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"b0bea894-90d3-4c34-b34a-87bca62156d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.0667111225836543`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.1420967813805453`", " ", 
     SuperscriptBox["e", "2"]}], "-", 
    RowBox[{"0.5683871255221813`", " ", 
     SuperscriptBox["s", "2"]}], "+", 
    RowBox[{"0.1420967813805453`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["e", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}], "-", 
    RowBox[{"0.5683871255221813`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["s", "\[Prime]",
        MultilineFunction->None], ")"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.16540618770008275`"}], " ", "e", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CurlyPi]", "-", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}], "]"}], " ", 
    SuperscriptBox["e", "\[Prime]",
     MultilineFunction->None]}], ",", 
   RowBox[{"1.1367742510443626`", " ", "s", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CapitalOmega]", "-", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}], "]"}], " ", 
    SuperscriptBox["s", "\[Prime]",
     MultilineFunction->None]}]}], "}"}]], "Output",
 CellChangeTimes->{3.866436981568671*^9, 3.866437264750966*^9, 
  3.8664374342144823`*^9, 3.8909742328569517`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"aae6f895-3523-425b-a823-cbf37dad82d4"]
}, Open  ]],

Cell["... and the resonant arguments.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"53613792-9c4b-4914-8fed-099ac1401055"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resterms", " ", "=", " ", "\n", 
  RowBox[{"resonant", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[ScriptCapitalG]", "->", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"m", "'"}], "->", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"a", "'"}], "->", "1"}], ",", "\n", " ", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"s_", ",", " ", "j_", ",", " ", "nd_"}], "]"}], " ", ":>", " ", 
      RowBox[{"LaplaceCoefficient", "[", 
       RowBox[{"s", ",", "j", ",", "\[Alpha]", ",", "nd"}], "]"}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.8664369956610327`*^9, 3.8664369956748734`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"9b569df9-552a-4744-b168-10d4b434788f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.5980998567783975`", " ", 
    SuperscriptBox["e", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", " ", "\[CurlyPi]"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2.211242820719656`"}], " ", "e", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "+", "\[CurlyPi]", "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "+", 
      SuperscriptBox["\[CurlyPi]", "\[Prime]",
       MultilineFunction->None]}], "]"}], " ", 
    SuperscriptBox["e", "\[Prime]",
     MultilineFunction->None]}], ",", 
   RowBox[{"0.362954034543187`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[CurlyPi]", "\[Prime]",
        MultilineFunction->None]}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["e", "\[Prime]",
       MultilineFunction->None], ")"}], "2"]}], ",", 
   RowBox[{"0.3308123754001657`", " ", 
    SuperscriptBox["s", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", " ", "\[CapitalOmega]"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.6616247508003315`"}], " ", "s", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "+", "\[CapitalOmega]", "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "+", 
      SuperscriptBox["\[CapitalOmega]", "\[Prime]",
       MultilineFunction->None]}], "]"}], " ", 
    SuperscriptBox["s", "\[Prime]",
     MultilineFunction->None]}], ",", 
   RowBox[{"0.3308123754001657`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Lambda]", "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Lambda]", "\[Prime]",
        MultilineFunction->None]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[CapitalOmega]", "\[Prime]",
        MultilineFunction->None]}]}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox["s", "\[Prime]",
       MultilineFunction->None], ")"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8664369968553*^9, 3.866437264795463*^9, 
  3.866437434265279*^9, 3.890974232876122*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"334f7e12-14d9-4492-af10-620db69169ef"]
}, Open  ]],

Cell[TextData[{
 "The numerical values of ",
 StyleBox["secterms", "Input"],
 " and ",
 StyleBox["resterms", "Input"],
 " are identical to those given in Table 6.1.  However, we can also make use \
of the explicit expressions given in Eqs.(6.195)\[Dash](6.205) to check these \
values.  Here we use the defined function ",
 StyleBox["LaplaceSeries", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"abf5808d-b369-4b28-9e7a-f36bfe0c89fd"],

Cell[CellGroupData[{

Cell["?LaplaceSeries", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"70a60d51-c882-4c3d-acb8-c7750106ed9e"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   FrameBox[
    DynamicModuleBox[{System`InformationDump`open$$ = False, 
     System`InformationDump`mouseOver$$ = False}, 
     PaneSelectorBox[{True->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False,
             BaseStyle -> None],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"LaplaceSeries[s,j,a,n,pw] gives the nth derivative \
of the Laplace coefficient b(s,j)(a) as a series in a up to and including \
terms of order pw.  s is a half-integer (e.g. 1/2, 3/2); j, n and pw are \
integers.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          PaneBox[
           TagBox[GridBox[{
              {
               StyleBox[
                TagBox[
                 TooltipBox[
                  StyleBox["\<\" Definitions\"\>", "InformationRowLabel",
                   StripOnInput->False],
                  "\"Definitions\"",
                  TooltipStyle->"TextStyling"],
                 Annotation[#, "Definitions", "Tooltip"]& ], "DialogStyle",
                StripOnInput->False]},
              {
               TemplateBox[{"\"\[ThinSpace]\"", 
                 GridBox[{{
                    RowBox[{
                    RowBox[{"LaplaceSeries", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`s_", ",", 
                    "DisturbingFunction`Private`j_Integer", ",", 
                    "DisturbingFunction`Private`alpha_", ",", 
                    "DisturbingFunction`Private`n_Integer", ",", 
                    "DisturbingFunction`Private`nord_Integer"}], "]"}], ":=", 
                    
                    RowBox[{
                    RowBox[{"LaplaceSeries", "[", 
                    RowBox[{"DisturbingFunction`Private`s", ",", 
                    RowBox[{"-", "DisturbingFunction`Private`j"}], ",", 
                    "DisturbingFunction`Private`alpha", ",", 
                    "DisturbingFunction`Private`n", ",", 
                    "DisturbingFunction`Private`nord"}], "]"}], "/;", 
                    RowBox[{"DisturbingFunction`Private`j", "<", "0"}]}]}]}, {
                   " "}, {
                    RowBox[{
                    RowBox[{"LaplaceSeries", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`s_", ",", 
                    "DisturbingFunction`Private`j_Integer", ",", 
                    "DisturbingFunction`Private`alpha_", ",", "0", ",", 
                    "DisturbingFunction`Private`nord_Integer"}], "]"}], ":=", 
                    
                    RowBox[{"Block", "[", 
                    RowBox[{
                    RowBox[{"{", "DisturbingFunction`Private`ifact", "}"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"DisturbingFunction`Private`j", "\[Equal]", "0"}],
                     ",", 
                    RowBox[{"DisturbingFunction`Private`ifact", "=", "2"}], 
                    ",", 
                    RowBox[{"DisturbingFunction`Private`ifact", "=", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"DisturbingFunction`Private`ii", "=", "0"}], 
                    RowBox[{"DisturbingFunction`Private`j", "-", "1"}]], 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`ii"}], ")"}]}], ")"}], " ", 
                    SuperscriptBox[
                    "DisturbingFunction`Private`alpha", 
                    "DisturbingFunction`Private`j"]}], 
                    RowBox[{"DisturbingFunction`Private`j", "!"}]]}]}], "]"}],
                     ";", 
                    RowBox[{"Expand", "[", 
                    RowBox[{"DisturbingFunction`Private`ifact", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"DisturbingFunction`Private`ii", "=", "1"}], 
                    FractionBox[
                    
                    RowBox[{"DisturbingFunction`Private`nord", "-", 
                    "DisturbingFunction`Private`j"}], "2"]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Product]", 
                    RowBox[{"DisturbingFunction`Private`jj", "=", "1"}], 
                    "DisturbingFunction`Private`ii"], 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`jj", "-", "1"}], ")"}], " ", 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`s", "+", 
                    "DisturbingFunction`Private`j", "+", 
                    "DisturbingFunction`Private`jj", "-", "1"}], ")"}]}], 
                    RowBox[{"DisturbingFunction`Private`jj", " ", 
                    RowBox[{"(", 
                    
                    RowBox[{"DisturbingFunction`Private`j", "+", 
                    "DisturbingFunction`Private`jj"}], ")"}]}]]}], ")"}], " ", 
                    SuperscriptBox["DisturbingFunction`Private`alpha", 
                    
                    RowBox[{"2", " ", 
                    "DisturbingFunction`Private`ii"}]]}]}]}], ")"}]}], 
                    "]"}]}]}], "]"}]}]}, {" "}, {
                    RowBox[{
                    RowBox[{"LaplaceSeries", "[", 
                    
                    RowBox[{
                    "DisturbingFunction`Private`s_", ",", 
                    "DisturbingFunction`Private`j_Integer", ",", 
                    "DisturbingFunction`Private`alpha_", ",", 
                    "DisturbingFunction`Private`n_Integer", ",", 
                    "DisturbingFunction`Private`nord_Integer"}], "]"}], ":=", 
                    
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[PartialD]", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{"DisturbingFunction`Private`alpha", ",", 
                    "DisturbingFunction`Private`n"}], "}"}]}]], 
                    RowBox[{"LaplaceSeries", "[", 
                    
                    RowBox[{"DisturbingFunction`Private`s", ",", 
                    "DisturbingFunction`Private`j", ",", 
                    "DisturbingFunction`Private`alpha", ",", "0", ",", 
                    
                    RowBox[{"DisturbingFunction`Private`nord", "+", 
                    "DisturbingFunction`Private`n"}]}], "]"}]}], "/;", 
                    RowBox[{"DisturbingFunction`Private`n", ">", "0"}]}]}]}, {
                   " "}}, GridBoxAlignment -> {"Columns" -> {{Left}}}, 
                  DefaultBaseStyle -> "Column", 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]},
                "RowDefault"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            "Column"],
           FrameMargins->{{6, 0}, {3, 6}}], "\<\"\"\>"},
         {
          PaneBox[GridBox[{
             {
              
              DynamicModuleBox[{System`InformationDump`open$$ = {
               False, False, False, False, False, False}}, 
               StyleBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Attributes\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"Attributes\"",
                    TooltipStyle->"TextStyling"],
                    Annotation[#, "Attributes", "Tooltip"]& ], 
                   RowBox[{"{", "Protected", "}"}]},
                  {
                   TagBox[
                    TooltipBox[
                    StyleBox["\<\" Full Name\"\>", "InformationRowLabel",
                    StripOnInput->False],
                    "\"FullName\"",
                    TooltipStyle->"TextStyling"],
                    
                    Annotation[#, "FullName", 
                    "Tooltip"]& ], \
"\<\"DisturbingFunction`LaplaceSeries\"\>"}
                 },
                 AutoDelete->False,
                 GridBoxAlignment->{"Columns" -> {Right, Left}},
                 GridBoxDividers->None,
                 GridBoxItemSize->{"Columns" -> {Automatic, Automatic}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "Rows" -> {
                    Offset[0.2], {
                    Offset[0.8]}, 
                    Offset[0.2]}}], "DialogStyle",
                StripOnInput->False],
               DynamicModuleValues:>{}]}
            },
            DefaultBaseStyle->"Column",
            GridBoxAlignment->{"Columns" -> {{Left}}},
            GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.5599999999999999]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[3.6]}, 
                Offset[0.2]}}],
           FrameMargins->{{6, 6}, {6, 3}}], ""},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpener"]], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "UpPointerOpenerHot"]]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, False],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"], False->
      TagBox[GridBox[{
         {
          ItemBox[
           PaneBox[
            StyleBox["\<\" Symbol\"\>", "InformationTitleText",
             StripOnInput->False],
            FrameMargins->{{4, 0}, {-1, 1}}],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           PaneBox[
            
            StyleBox["\<\"LaplaceSeries[s,j,a,n,pw] gives the nth derivative \
of the Laplace coefficient b(s,j)(a) as a series in a up to and including \
terms of order pw.  s is a half-integer (e.g. 1/2, 3/2); j, n and pw are \
integers.\"\>", "InformationUsageText",
             StripOnInput->False,
             LineSpacing->{1.5, 1.5, 3.}],
            FrameMargins->{{10, 10}, {8, 10}}],
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False], 
          ItemBox["\<\"\"\>",
           BaseStyle->"InformationUsageSubtitleBackground",
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            ButtonBox[
             PaneSelectorBox[{False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpener"],
               ImageSizeCache->{10., {2., 8.}}], True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "DownPointerOpenerHot"],
               ImageSizeCache->{10., {2., 8.}}]}, Dynamic[
              System`InformationDump`mouseOver$$]],
             Alignment->Left,
             Appearance->{"Default" -> None},
             
             ButtonFunction:>FEPrivate`Set[
              System`InformationDump`open$$, True],
             Evaluator->Automatic,
             FrameMargins->{{9, 0}, {0, 0}},
             ImageMargins->0,
             ImageSize->Full,
             Method->"Preemptive"],
            
            EventHandlerTag[{
             "MouseEntered" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, True], 
              "MouseExited" :> 
              FEPrivate`Set[System`InformationDump`mouseOver$$, False], 
              Method -> "Preemptive", PassEventsDown -> Automatic, 
              PassEventsUp -> True}]],
           BaseStyle->"InformationTitleBackground",
           StripOnInput->False], "\[SpanFromLeft]"}
        },
        AutoDelete->False,
        FrameStyle->Directive[
          GrayLevel[0.8], 
          Thickness[Tiny]],
        GridBoxAlignment->{"Columns" -> {Left, Right}, "Rows" -> {{Center}}},
        GridBoxDividers->{
         "Columns" -> {{None}}, "Rows" -> {False, {True}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
       "Grid"]}, Dynamic[System`InformationDump`open$$],
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     DynamicModuleValues:>{}],
    BaseStyle->"InformationGridFrame",
    StripOnInput->False], "InformationGridPlain",
   StripOnInput->False],
  InformationData[<|
   "ObjectType" -> "Symbol", "Usage" -> 
    "LaplaceSeries[s,j,a,n,pw] gives the nth derivative of the Laplace \
coefficient b(s,j)(a) as a series in a up to and including terms of order pw. \
 s is a half-integer (e.g. 1/2, 3/2); j, n and pw are integers.", 
    "Documentation" -> None, "OwnValues" -> None, "UpValues" -> None, 
    "DownValues" -> 
    Information`InformationValueForm[
     DownValues, DisturbingFunction`LaplaceSeries, {
      DisturbingFunction`LaplaceSeries[
         Pattern[DisturbingFunction`Private`s, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`j, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`alpha, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`n, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`nord, 
          Blank[Integer]]] :> Condition[
         DisturbingFunction`LaplaceSeries[
         DisturbingFunction`Private`s, -DisturbingFunction`Private`j, 
          DisturbingFunction`Private`alpha, DisturbingFunction`Private`n, 
          DisturbingFunction`Private`nord], DisturbingFunction`Private`j < 0],
        DisturbingFunction`LaplaceSeries[
         Pattern[DisturbingFunction`Private`s, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`j, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`alpha, 
          Blank[]], 0, 
         Pattern[DisturbingFunction`Private`nord, 
          Blank[Integer]]] :> 
       Block[{DisturbingFunction`Private`ifact}, 
         If[DisturbingFunction`Private`j == 0, 
           DisturbingFunction`Private`ifact = 2, 
           DisturbingFunction`Private`ifact = (2/Factorial[
             DisturbingFunction`Private`j]) 
            Product[DisturbingFunction`Private`s + 
              DisturbingFunction`Private`ii, {
              DisturbingFunction`Private`ii, 0, DisturbingFunction`Private`j - 
               1}] 
            DisturbingFunction`Private`alpha^DisturbingFunction`Private`j]; 
         Expand[DisturbingFunction`Private`ifact (1 + 
            Sum[Product[(DisturbingFunction`Private`s + 
                 DisturbingFunction`Private`jj - 
                 1) ((DisturbingFunction`Private`s + 
                  DisturbingFunction`Private`j + 
                  DisturbingFunction`Private`jj - 1)/(
                 DisturbingFunction`Private`jj (DisturbingFunction`Private`j + 
                  DisturbingFunction`Private`jj))), {
                DisturbingFunction`Private`jj, 1, 
                 DisturbingFunction`Private`ii}] 
              DisturbingFunction`Private`alpha^(2 
                DisturbingFunction`Private`ii), {
              DisturbingFunction`Private`ii, 
               1, (DisturbingFunction`Private`nord - 
                DisturbingFunction`Private`j)/2}])]], 
       DisturbingFunction`LaplaceSeries[
         Pattern[DisturbingFunction`Private`s, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`j, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`alpha, 
          Blank[]], 
         Pattern[DisturbingFunction`Private`n, 
          Blank[Integer]], 
         Pattern[DisturbingFunction`Private`nord, 
          Blank[Integer]]] :> Condition[
         D[
          DisturbingFunction`LaplaceSeries[
          DisturbingFunction`Private`s, DisturbingFunction`Private`j, 
           DisturbingFunction`Private`alpha, 0, 
           DisturbingFunction`Private`nord + DisturbingFunction`Private`n], {
          DisturbingFunction`Private`alpha, DisturbingFunction`Private`n}], 
         DisturbingFunction`Private`n > 0]}], "SubValues" -> None, 
    "DefaultValues" -> None, "NValues" -> None, "FormatValues" -> None, 
    "Options" -> None, "Attributes" -> {Protected}, "FullName" -> 
    "DisturbingFunction`LaplaceSeries"|>, False]]], "Output",
 CellChangeTimes->{3.811324375379554*^9, 3.8664370069337997`*^9, 
  3.866437264877755*^9, 3.86643743434809*^9, 3.890974232948038*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"69b8935f-0ba6-4b91-a50c-3acfeb4e85e9"]
}, Open  ]],

Cell[TextData[{
 "Now we can find the values of ",
 StyleBox["a0", "Input"],
 ", ",
 StyleBox["a1", "Input"],
 ", ..., ",
 StyleBox["a10", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0dd26083-93b8-480e-98fe-c14b1e4ea3d3"],

Cell[CellGroupData[{

Cell["a0 = LaplaceSeries[1/2,0,\[Alpha],0,30]/2", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"758d2086-02f2-43cd-b7d4-36a7b76244c2"],

Cell[BoxData["1.0667111225820112`"], "Output",
 CellChangeTimes->{3.811324375385203*^9, 3.86643701224144*^9, 
  3.866437264913501*^9, 3.866437434376905*^9, 3.890974232957407*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"190c05b8-b74f-444a-a7ff-e0c67ae2aad0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "8"}], ")"}], "*", 
    RowBox[{"(", "\n", 
     RowBox[{
      RowBox[{"2", "*", "\[Alpha]", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "0", ",", "aa", ",", "1", ",", "30"}], 
        "]"}]}], "+", "\n", 
      RowBox[{
       RowBox[{"\[Alpha]", "^", "2"}], "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "0", ",", "aa", ",", "2", ",", "30"}], 
        "]"}]}]}], ")"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437024911734*^9, 3.866437024925294*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"eac07eee-8aaf-431e-9b81-676e8acc3448"],

Cell[BoxData["0.142096781249927`"], "Output",
 CellChangeTimes->{3.866437027020276*^9, 3.866437264953926*^9, 
  3.866437434424107*^9, 3.890974232974843*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"9dfc84be-07d1-4ae4-805b-cf065ebd3aed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", 
    RowBox[{"(", "\n", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], "*", 
      RowBox[{"LaplaceSeries", "[", 
       RowBox[{
        RowBox[{"3", "/", "2"}], ",", "1", ",", "aa", ",", "0", ",", "30"}], 
       "]"}]}], ")"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437040406794*^9, 3.866437040420933*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"2aebe338-d27d-43f5-bd9a-7c8b6b4f2041"],

Cell[BoxData[
 RowBox[{"-", "0.5683871237248864`"}]], "Output",
 CellChangeTimes->{3.866437041602406*^9, 3.866437264984804*^9, 
  3.866437434450417*^9, 3.8909742329827957`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"eb1770de-fa6e-4072-9197-f0127aff670b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "4"}], ")"}], "*", 
    RowBox[{"(", "\n", "    ", 
     RowBox[{
      RowBox[{"2", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "0", ",", "30"}], 
        "]"}]}], "\n", "-", 
      RowBox[{"2", "*", "aa", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "1", ",", "30"}], 
        "]"}]}], "\n", "-", 
      RowBox[{
       RowBox[{"aa", "^", "2"}], "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "2", ",", "30"}], 
        "]"}]}]}], "\n", ")"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437054403466*^9, 3.866437054417399*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"e54063c4-5ddb-4ac3-a774-fc8c81845cb7"],

Cell[BoxData[
 RowBox[{"-", "0.16540618725847456`"}]], "Output",
 CellChangeTimes->{3.866437056229143*^9, 3.866437265023134*^9, 
  3.866437434499278*^9, 3.890974233000736*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"32e45541-ce9a-453c-8743-d6590b4d93d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{"aa", "*", 
    RowBox[{"LaplaceSeries", "[", 
     RowBox[{
      RowBox[{"3", "/", "2"}], ",", "1", ",", "aa", ",", "0", ",", "30"}], 
     "]"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.8664370715774727`*^9, 3.8664370715924397`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"7a1f060e-b902-44f8-b617-6d704cef4084"],

Cell[BoxData["1.1367742474497728`"], "Output",
 CellChangeTimes->{3.866437073329969*^9, 3.8664372650516*^9, 
  3.866437434524961*^9, 3.8909742330081873`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"17323d89-71f5-4bb9-8211-b1b98b6a747a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a5", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "8"}], ")"}], "*", 
    RowBox[{"(", "\n", "    ", 
     RowBox[{
      RowBox[{"21", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "3", ",", "aa", ",", "0", ",", "30"}], 
        "]"}]}], "\n", "+", 
      RowBox[{"10", "*", "aa", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "3", ",", "aa", ",", "1", ",", "30"}], 
        "]"}]}], "\n", "+", 
      RowBox[{
       RowBox[{"aa", "^", "2"}], "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "3", ",", "aa", ",", "2", ",", "30"}], 
        "]"}]}]}], "\n", ")"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437086637219*^9, 3.866437086654331*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"9e5480f8-d4a3-409f-a63f-b1caf8e61f31"],

Cell[BoxData["0.5980998564848325`"], "Output",
 CellChangeTimes->{3.866437087729105*^9, 3.86643726508813*^9, 
  3.8664374345740557`*^9, 3.89097423302607*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"070f7b5e-e5e5-48b2-9ba5-cfbe77a7a6bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a6", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "4"}], ")"}], "*", 
    RowBox[{"(", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "20"}], "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "2", ",", "aa", ",", "0", ",", "30"}], 
        "]"}]}], "\n", "-", 
      RowBox[{"10", "*", "aa", "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "2", ",", "aa", ",", "1", ",", "30"}], 
        "]"}]}], "\n", "-", 
      RowBox[{
       RowBox[{"aa", "^", "2"}], "*", 
       RowBox[{"LaplaceSeries", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], ",", "2", ",", "aa", ",", "2", ",", "30"}], 
        "]"}]}]}], "\n", ")"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437103499919*^9, 3.8664371035139093`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"2b80a588-d3ca-4774-9c0d-5969453c9c4a"],

Cell[BoxData[
 RowBox[{"-", "2.2112428202271763`"}]], "Output",
 CellChangeTimes->{3.8664371050412817`*^9, 3.8664372651716433`*^9, 
  3.8664374346731873`*^9, 3.890974233034073*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"adf828a7-532e-4e0b-b54b-24feead66dce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a7", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "8"}], ")"}], "*", 
     RowBox[{"(", "\n", "    ", 
      RowBox[{
       RowBox[{"17", "*", 
        RowBox[{"LaplaceSeries", "[", 
         RowBox[{
          RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "0", ",", "30"}],
          "]"}]}], "\n", "+", 
       RowBox[{"10", "*", "aa", "*", 
        RowBox[{"LaplaceSeries", "[", 
         RowBox[{
          RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "1", ",", "30"}],
          "]"}]}], "\n", " ", "+", 
       RowBox[{
        RowBox[{"aa", "^", "2"}], "*", 
        RowBox[{"LaplaceSeries", "[", 
         RowBox[{
          RowBox[{"1", "/", "2"}], ",", "1", ",", "aa", ",", "2", ",", "30"}],
          "]"}]}]}], ")"}]}], "-", "\n", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"27", "/", "8"}], ")"}], "*", "aa"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.8664371183354397`*^9, 3.866437118348977*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"385e41b0-072f-4dca-8eae-f1903ffb115b"],

Cell[BoxData["0.36295403425417105`"], "Output",
 CellChangeTimes->{3.86643712207833*^9, 3.86643726519731*^9, 
  3.866437434722198*^9, 3.890974233051855*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"1a16d3f2-4a86-412e-af1b-18724a94ea64"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a8", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", "aa", "*", 
    RowBox[{"LaplaceSeries", "[", 
     RowBox[{
      RowBox[{"3", "/", "2"}], ",", "2", ",", "aa", ",", "0", ",", "30"}], 
     "]"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437133830051*^9, 3.866437133843729*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"559b2afd-8180-4d4d-8556-c7d1907a974c"],

Cell[BoxData["0.3308123745114286`"], "Output",
 CellChangeTimes->{3.866437134542782*^9, 3.866437265230081*^9, 
  3.8664374347474833`*^9, 3.890974233059173*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"24fd80b8-1501-4e6c-b3b1-8dcb9f2b0e99"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a9", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "aa"}], "*", 
    RowBox[{"LaplaceSeries", "[", 
     RowBox[{
      RowBox[{"3", "/", "2"}], ",", "2", ",", "aa", ",", "0", ",", "30"}], 
     "]"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.8664371479585123`*^9, 3.8664371479723463`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"756b2797-bff2-495a-857c-526872c32324"],

Cell[BoxData[
 RowBox[{"-", "0.6616247490228572`"}]], "Output",
 CellChangeTimes->{3.866437148674739*^9, 3.866437265253771*^9, 
  3.866437434794457*^9, 3.890974233076147*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"1857341e-8c6c-4500-ba88-52be041bb7df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a10", " ", "=", " ", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", "aa", "*", 
    RowBox[{"LaplaceSeries", "[", 
     RowBox[{
      RowBox[{"3", "/", "2"}], ",", "2", ",", "aa", ",", "0", ",", "30"}], 
     "]"}]}], " ", "/.", " ", 
   RowBox[{"aa", "->", "\[Alpha]"}]}]}]], "Input",
 CellChangeTimes->{{3.866437160512927*^9, 3.866437160526494*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"caadd2cc-4de8-4817-a992-cd3c01efeba9"],

Cell[BoxData["0.3308123745114286`"], "Output",
 CellChangeTimes->{3.8664371610354357`*^9, 3.866437265287128*^9, 
  3.8664374348195066`*^9, 3.8909742330835648`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"a7c3fed7-ed03-42e7-9240-0b4415da0b78"]
}, Open  ]],

Cell["\<\
Again we can compare these values with those given in Table 6.1.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1a7f3f3f-d750-4731-90b7-0cf35acd5d9f"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "10"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
      "a0", ",", "a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6", 
       ",", "a7", ",", "a8", ",", "a9", ",", "a10"}], "}"}]}], "}"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"172ec70a-2311-42f2-b501-87bcdc65727b"],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", "1.0667111225820112`"},
    {"1", "0.142096781249927`"},
    {"2", 
     RowBox[{"-", "0.5683871237248864`"}]},
    {"3", 
     RowBox[{"-", "0.16540618725847456`"}]},
    {"4", "1.1367742474497728`"},
    {"5", "0.5980998564848325`"},
    {"6", 
     RowBox[{"-", "2.2112428202271763`"}]},
    {"7", "0.36295403425417105`"},
    {"8", "0.3308123745114286`"},
    {"9", 
     RowBox[{"-", "0.6616247490228572`"}]},
    {"10", "0.3308123745114286`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8664371752703667`*^9, 3.8664372653083878`*^9, 
  3.86643743486444*^9, 3.890974233101342*^9},
 CellLabel->
  "Out[25]//TableForm=",ExpressionUUID->"dcdc7caa-1757-4d07-ad7f-\
6ac7c21e2527"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1010, 658},
WindowMargins->{{82, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"19f270fc-c267-4c2d-b58a-44b9641c2962"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"7c6823d8-1b6d-47fd-94fe-e17171908c1c"],
Cell[1000, 31, 99, 0, 67, "Section",ExpressionUUID->"b8a4dc82-9288-43ab-86c8-ca741bc20902"],
Cell[1102, 33, 541, 12, 141, "Text",ExpressionUUID->"3765bf77-314d-4213-952a-f7910528cb4d"],
Cell[1646, 47, 190, 2, 30, "Input",ExpressionUUID->"2625adf5-311e-4bc8-8a25-c1ef671c42e0"],
Cell[1839, 51, 150, 2, 30, "Input",ExpressionUUID->"b32a3cee-6374-49ef-816a-ff3d748c8f77"],
Cell[1992, 55, 215, 7, 53, "Text",ExpressionUUID->"90bc5eae-1a96-4345-891f-d5eb1fb9e062"],
Cell[CellGroupData[{
Cell[2232, 66, 135, 2, 30, "Input",ExpressionUUID->"a11ae7ed-cb99-4dd5-8cd0-d6b5b201628b"],
Cell[2370, 70, 32476, 691, 143, "Output",ExpressionUUID->"20ee3eb5-758c-49ef-aace-5cd4e914e389"]
}, Open  ]],
Cell[34861, 764, 444, 10, 76, "Text",ExpressionUUID->"260ff44d-3a45-458e-9e78-123e4f85f663"],
Cell[CellGroupData[{
Cell[35330, 778, 157, 2, 30, "Input",ExpressionUUID->"31211f09-0101-4959-9ef7-d9361c9da52b"],
Cell[35490, 782, 608, 14, 34, "Output",ExpressionUUID->"432c14a3-3ce8-4081-a45d-03c2803faac4"]
}, Open  ]],
Cell[36113, 799, 220, 7, 53, "Text",ExpressionUUID->"0d6cb01a-674d-4d84-b09a-6753d329ac6b"],
Cell[CellGroupData[{
Cell[36358, 810, 140, 2, 30, "Input",ExpressionUUID->"ac212f06-4691-4f7b-a713-dcc098d035fa"],
Cell[36501, 814, 17391, 402, 119, "Output",ExpressionUUID->"a77ee3af-224e-4f87-a278-48ec045005f5"]
}, Open  ]],
Cell[53907, 1219, 298, 8, 53, "Text",ExpressionUUID->"66038f9b-3952-4f07-871c-d7d9902f4959"],
Cell[CellGroupData[{
Cell[54230, 1231, 174, 2, 30, "Input",ExpressionUUID->"e3713d9e-94cd-4d07-8949-6d34b274f4c5"],
Cell[54407, 1235, 4245, 115, 139, "Output",ExpressionUUID->"68d16c21-7636-4886-8a3e-3b98f5237e79"]
}, Open  ]],
Cell[58667, 1353, 338, 8, 76, "Text",ExpressionUUID->"e9805ec4-b033-45f7-a9e4-a1a32320b609"],
Cell[CellGroupData[{
Cell[59030, 1365, 158, 2, 30, "Input",ExpressionUUID->"6022d9e9-3b16-4b78-abc9-087d480a87e1"],
Cell[59191, 1369, 1153, 31, 56, "Output",ExpressionUUID->"39d7d848-981a-4eb6-96b4-abcdab884dde"]
}, Open  ]],
Cell[60359, 1403, 299, 8, 53, "Text",ExpressionUUID->"2712ef4c-b71f-4f10-a35b-baac361bb4c4"],
Cell[CellGroupData[{
Cell[60683, 1415, 175, 2, 30, "Input",ExpressionUUID->"72fead30-71ba-4d61-b903-5a0680739fc5"],
Cell[60861, 1419, 7270, 197, 216, "Output",ExpressionUUID->"b51c1907-5573-4757-823a-0bfe67249ea5"]
}, Open  ]],
Cell[68146, 1619, 240, 6, 53, "Text",ExpressionUUID->"fe8d2a07-1fd8-4b78-979a-90242bdc7820"],
Cell[CellGroupData[{
Cell[68411, 1629, 177, 2, 30, "Input",ExpressionUUID->"f124f71d-c80f-4d13-a5e3-524a674bf933"],
Cell[68591, 1633, 261, 3, 34, "Output",ExpressionUUID->"e97f855a-6950-4286-a864-91aa9f4baef2"]
}, Open  ]],
Cell[68867, 1639, 219, 7, 53, "Text",ExpressionUUID->"73613459-2158-445a-9de8-827677fe456c"],
Cell[CellGroupData[{
Cell[69111, 1650, 140, 2, 30, "Input",ExpressionUUID->"e3683508-4f23-42f8-805e-6e85ecc05d6d"],
Cell[69254, 1654, 18631, 414, 119, "Output",ExpressionUUID->"fc216080-266c-4c4a-a5bb-f377c82b8afa"]
}, Open  ]],
Cell[87900, 2071, 218, 6, 53, "Text",ExpressionUUID->"644a6206-4520-4e97-a620-0b87ba704d4c"],
Cell[CellGroupData[{
Cell[88143, 2081, 721, 17, 73, "Input",ExpressionUUID->"b0bea894-90d3-4c34-b34a-87bca62156d6"],
Cell[88867, 2100, 1408, 35, 37, "Output",ExpressionUUID->"aae6f895-3523-425b-a823-cbf37dad82d4"]
}, Open  ]],
Cell[90290, 2138, 157, 3, 53, "Text",ExpressionUUID->"53613792-9c4b-4914-8fed-099ac1401055"],
Cell[CellGroupData[{
Cell[90472, 2145, 724, 17, 73, "Input",ExpressionUUID->"9b569df9-552a-4744-b168-10d4b434788f"],
Cell[91199, 2164, 2659, 69, 60, "Output",ExpressionUUID->"334f7e12-14d9-4492-af10-620db69169ef"]
}, Open  ]],
Cell[93873, 2236, 486, 13, 76, "Text",ExpressionUUID->"abf5808d-b369-4b28-9e7a-f36bfe0c89fd"],
Cell[CellGroupData[{
Cell[94384, 2253, 142, 2, 30, "Input",ExpressionUUID->"70a60d51-c882-4c3d-acb8-c7750106ed9e"],
Cell[94529, 2257, 19588, 446, 119, "Output",ExpressionUUID->"69b8935f-0ba6-4b91-a50c-3acfeb4e85e9"]
}, Open  ]],
Cell[114132, 2706, 275, 11, 53, "Text",ExpressionUUID->"0dd26083-93b8-480e-98fe-c14b1e4ea3d3"],
Cell[CellGroupData[{
Cell[114432, 2721, 169, 2, 30, "Input",ExpressionUUID->"758d2086-02f2-43cd-b7d4-36a7b76244c2"],
Cell[114604, 2725, 257, 3, 34, "Output",ExpressionUUID->"190c05b8-b74f-444a-a7ff-e0c67ae2aad0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114898, 2733, 806, 21, 73, "Input",ExpressionUUID->"eac07eee-8aaf-431e-9b81-676e8acc3448"],
Cell[115707, 2756, 235, 3, 34, "Output",ExpressionUUID->"9dfc84be-07d1-4ae4-805b-cf065ebd3aed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115979, 2764, 574, 15, 52, "Input",ExpressionUUID->"2aebe338-d27d-43f5-bd9a-7c8b6b4f2041"],
Cell[116556, 2781, 255, 4, 34, "Output",ExpressionUUID->"eb1770de-fa6e-4072-9197-f0127aff670b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116848, 2790, 1002, 26, 136, "Input",ExpressionUUID->"e54063c4-5ddb-4ac3-a774-fc8c81845cb7"],
Cell[117853, 2818, 254, 4, 34, "Output",ExpressionUUID->"32e45541-ce9a-453c-8743-d6590b4d93d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118144, 2827, 440, 10, 52, "Input",ExpressionUUID->"7a1f060e-b902-44f8-b617-6d704cef4084"],
Cell[118587, 2839, 236, 3, 34, "Output",ExpressionUUID->"17323d89-71f5-4bb9-8211-b1b98b6a747a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118860, 2847, 1004, 26, 136, "Input",ExpressionUUID->"9e5480f8-d4a3-409f-a63f-b1caf8e61f31"],
Cell[119867, 2875, 236, 3, 34, "Output",ExpressionUUID->"070f7b5e-e5e5-48b2-9ba5-cfbe77a7a6bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120140, 2883, 1029, 27, 136, "Input",ExpressionUUID->"2b80a588-d3ca-4774-9c0d-5969453c9c4a"],
Cell[121172, 2912, 259, 4, 34, "Output",ExpressionUUID->"adf828a7-532e-4e0b-b54b-24feead66dce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121468, 2921, 1141, 30, 136, "Input",ExpressionUUID->"385e41b0-072f-4dca-8eae-f1903ffb115b"],
Cell[122612, 2953, 235, 3, 34, "Output",ExpressionUUID->"1a16d3f2-4a86-412e-af1b-18724a94ea64"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122884, 2961, 497, 12, 52, "Input",ExpressionUUID->"559b2afd-8180-4d4d-8556-c7d1907a974c"],
Cell[123384, 2975, 238, 3, 34, "Output",ExpressionUUID->"24fd80b8-1501-4e6c-b3b1-8dcb9f2b0e99"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123659, 2983, 460, 11, 52, "Input",ExpressionUUID->"756b2797-bff2-495a-857c-526872c32324"],
Cell[124122, 2996, 253, 4, 34, "Output",ExpressionUUID->"1857341e-8c6c-4500-ba88-52be041bb7df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124412, 3005, 498, 12, 52, "Input",ExpressionUUID->"caadd2cc-4de8-4817-a992-cd3c01efeba9"],
Cell[124913, 3019, 242, 3, 34, "Output",ExpressionUUID->"a7c3fed7-ed03-42e7-9240-0b4415da0b78"]
}, Open  ]],
Cell[125170, 3025, 198, 5, 53, "Text",ExpressionUUID->"1a7f3f3f-d750-4731-90b7-0cf35acd5d9f"],
Cell[125371, 3032, 508, 12, 73, "Input",ExpressionUUID->"172ec70a-2311-42f2-b501-87bcdc65727b"],
Cell[125882, 3046, 1070, 32, 215, "Output",ExpressionUUID->"dcdc7caa-1757-4d07-ad7f-6ac7c21e2527"]
}
]
*)

